==> dev-plugin-android-0.0.55-sources.jar: com/zoyi/channel/plugin/android/model/etc/Typing.java <==
package com.zoyi.channel.plugin.android.model.etc;

import com.zoyi.channel.plugin.android.ChannelStore;
import com.zoyi.channel.plugin.android.activity.chat.ChatDataDictionary;
import com.zoyi.channel.plugin.android.model.rest.ProfileEntity;

public class Typing {

  public static final long TTL = 30;

  private String action;
  private String chatId;
  private String chatType;
  private String personId;
  private String personType;
  private Long createdAt;

  public Typing(String action, String chatId, String chatType) {
    this.action = action;
    this.chatId = chatId;
    this.chatType = chatType;
  }

  public String getAction() {
    return action;
  }

  public void setAction(String action) {
    this.action = action;
  }

  public void setCreatedAt(Long createdAt) {
    this.createdAt = createdAt;
  }

  public boolean isOther() {
    String myPersonId = ChannelStore.getPersonId();
    return this.personId != null && myPersonId != null && !this.personId.equals(myPersonId);
  }

  public boolean isExpired() {
    return createdAt != null && (System.currentTimeMillis() - createdAt >= TTL);
  }

  public String getKey() {
    return String.format("%s:%s:%s:%s", chatId, chatType, personId, personType);
  }

  public ProfileEntity getProfileEntity(ChatDataDictionary dictionary) {
    if (dictionary == null) {
      return null;
    }
    return dictionary.getProfile(personType, personId);
  }

  public boolean isSameChat(String chatId, String chatType) {
    return this.chatId.equals(chatId) && this.chatType.equals(chatType);
  }

  @Override
  public boolean equals(Object o) {
    boolean ret = false;
    if (o != null && o instanceof Typing) {
      Typing next = (Typing) o;

      ret = this.chatId.equals(next.chatId)
          && this.chatType.equals(next.chatType)
          && this.personId.equals(next.personId)
          && this.personType.equals(next.personType);
    }
    return ret;
  }
}

==> dev-plugin-android-0.0.64-sources.jar: com/zoyi/channel/plugin/android/model/etc/Typing.java <==
package com.zoyi.channel.plugin.android.model.etc;

import com.zoyi.channel.plugin.android.ChannelStore;
import com.zoyi.channel.plugin.android.activity.chat.ChatDataDictionary;
import com.zoyi.channel.plugin.android.model.interfaces.ProfileEntity;

public class Typing {

  public static final long TTL = 30;

  private String action;
  private String chatId;
  private String chatType;
  private String personId;
  private String personType;
  private Long createdAt;

  public Typing(String action, String chatId, String chatType) {
    this.action = action;
    this.chatId = chatId;
    this.chatType = chatType;
  }

  public String getAction() {
    return action;
  }

  public void setAction(String action) {
    this.action = action;
  }

  public void setCreatedAt(Long createdAt) {
    this.createdAt = createdAt;
  }

  public boolean isOther() {
    String me = String.format("%s%s", ChannelStore.getPersonId(), ChannelStore.getPersonType());
    return !me.equals(String.format("%s%s", personId, personType));
  }

  public boolean isExpired() {
    return createdAt != null && (System.currentTimeMillis() - createdAt >= TTL);
  }

  public String getKey() {
    return String.format("%s:%s:%s:%s", chatId, chatType, personId, personType);
  }

  public ProfileEntity getProfileEntity(ChatDataDictionary dictionary) {
    if (dictionary == null) {
      return null;
    }
    return dictionary.getProfile(personType, personId);
  }

  public boolean isSameChat(String chatId, String chatType) {
    return this.chatId.equals(chatId) && this.chatType.equals(chatType);
  }

  @Override
  public boolean equals(Object o) {
    boolean ret = false;
    if (o != null && o instanceof Typing) {
      Typing next = (Typing) o;

      ret = this.chatId.equals(next.chatId)
          && this.chatType.equals(next.chatType)
          && this.personId.equals(next.personId)
          && this.personType.equals(next.personType);
    }
    return ret;
  }
}
